PyXMake Developer Guide: PyXMake.VTL.app Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.app Namespace Reference

## Functions
def | main (BuildID, script=VTL.GetSourceCode(8), source=__pyc_src_path, include=VTL.GetIncludeDirectory(os.path.dirname(__pyc_src_path), 8), dependency=VTL.GetLinkDependency(8), output=os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist"), encryption=True, mode="onefile", scratch=VTL.Scratch, verbosity=2, kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build a stand-alone python application")
| metavar
| nargs
| help
| args
| make_opt = args.make[0]
string | delimn = "&&"
string | command
| mode
| preprocessing

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile a stand-alone application using PyInstaller
    Created on 02.05.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          - Requires PyCODAC in PYTHONPATH.

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.app.main | ( |  | BuildID,
|  |  | script = `VTL.GetSourceCode(8)`,
|  |  | source = `__pyc_src_path`,
|  |  | include = `VTL.GetIncludeDirectory(os.path.dirname(__pyc_src_path), 8)`,
|  |  | dependency = `VTL.GetLinkDependency(8)`,
|  |  | output = `os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist")`,
|  |  | encryption = `True`,
|  |  | mode = `"onefile"`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `2`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 58 of file app.py.

## Variable Documentation

## ◆ command

string PyXMake.VTL.app.command

Initial value:
1 = delimn.join([
2 sys.executable,os.path.join(__pyc_src_path,"Plugin","DELiS","__install__.py"),continuation,
3 sys.executable,os.path.join(__pyc_src_path,"Plugin","DELiS","__update__.py"),continuation,
4 sys.executable,os.path.join(__pyc_src_path,"Plugin","Smetana","__install__.py"),continuation,
5 sys.executable,os.path.join(__pyc_src_path,"Plugin","Smetana","__update__.py")
6 ])

Definition at line 99 of file app.py.